from setuptools import setup

setup(name='mirs_distribution_package',
      version='1.0',
      description='Gaussian mirs_distribution_package',
      packages=['mirs_distribution_package'],
      zip_safe=False)
